from typing import List

# Funktionen
def list_to_float(data: List[str]) -> List[float]:
    """
    Converts a list of strings into a list of floats
    """
    float_list = []
    for i in data:
        float_list.append(float(i))
    return float_list

def mean(data: List[float]) -> float:
    """
    Calculates the mean value from a list of floats
    """
    return sum(data) / len(data)

def moving_average(data: List[float], window_size: int = 5) -> List[float]:
    """
    Calculates the moving average of a list of floats with a given window size
    Default window size is 5
    """
    mov_avg = []

    for current_index in range(1, len(data)+1):
        end = current_index
        start = current_index - window_size

        if start < 0:
            start = 0

        #print(f"Sublist from index {start} to index {end-1} is averaged")

        sub_list = data[start:end]
        mov_avg.append(sum(sub_list) / len(sub_list))

    return mov_avg

def mse(data1: List[float], data2: List[float]) -> float:
    """
    Calculates the mean squared error between two lists of floats
    """
    n = len(data1)
    mse_sum = 0.0

    for i in range(n):
        mse_sum = mse_sum + (data1[i] - data2[i])**2

    return mse_sum / n
